@@ -38,7 +38,7 @@ def make_batches(
         logger.debug(f"WIll be opening nwp file: {manager.config.input_data.nwp.nwp_zarr_path}")
 
     # make location file
-    manager.initialize_data_sources(names_of_selected_data_sources=["gsp", "nwp"])
+    manager.initialize_data_sources(names_of_selected_data_sources=["gsp", "nwp", "pv"])
     manager.create_files_specifying_spatial_and_temporal_locations_of_each_example(
         t0_datetime=t0_datetime_utc
     )
