@@ -15,7 +15,11 @@ from nowcasting_datamodel.models import (
     InputDataLastUpdatedSQL,
 )
 from nowcasting_datamodel.national import make_national_forecast
-from nowcasting_datamodel.read.read import get_location, get_model
+from nowcasting_datamodel.read.read import (
+    get_latest_input_data_last_updated,
+    get_location,
+    get_model,
+)
 from nowcasting_dataset.config.load import load_yaml_configuration
 from nowcasting_dataset.dataset.batch import Batch
 from sqlalchemy.orm.session import Session
@@ -60,7 +64,7 @@ def nwp_irradiance_simple_run_all_batches(
     # make dataloader
     dataloader = iter(BatchDataLoader(n_batches=n_batches, configuration=configuration))
 
-    input_data_last_updated = make_fake_input_data_last_updated()
+    input_data_last_updated = get_latest_input_data_last_updated(session=session)
 
     # loop over batch
     forecasts = []
